==> nextcloud-app-tasks-0.12.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/hu.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Fontos",
    "Today" : "Ma",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "Tasks" : "Feladatok",
    "The Tasks app for Nextcloud" : "Feladatok alkalmazás Nextcloud-hoz",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok.",
    "can edit" : "módosíthat ",
    "Unable to delete the share." : "Nem lehet törölni a megosztást.",
    "Unable to change permissions." : "Nem lehet változtatni az engedélyeket.",
    "New List" : "Új lista",
    "Cancel" : "Mégsem",
    "Save" : "Mentés",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Edit" : "Szerkesztés",
    "Copy private link" : "Személyes hivatkozás másolása",
    "Copied" : "Másolva",
    "Can not copy" : "Nem lehet másolni",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "Unshare" : "Megosztás visszavonása",
    "Calendar link copied to clipboard." : "Naptár hivatkozás a vágólapra másolva.",
    "Calendar link could not be copied to clipboard." : "Naptári hivatkozást nem lehet vágólapra másolni.",
    "Default list" : "Alapértelmezett lista",
    "Visibility of Smart Collections" : "Okos gyűjtemény láthatósága",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Automatikus",
    "Delete all completed tasks." : "Összes befejezett feladat törlése.",
    "Delete completed tasks." : "Befejezett feladatok törlése.",
    "No errors" : "Nincsenek hibák",
    "Open your browser console for more details" : "Nyisd meg a böngésző konzolját további részletekért",
    "Load all completed tasks." : "Összes befejezett feladat betöltése.",
    "Change sort order" : "Rendezési sorrend váltás",
    "Start date" : "Kezdő dátum",
    "Sort by start date and summary." : "Rendezés kezdő dátum és összefoglaló szerint.",
    "Due date" : "Lejárati dátum",
    "Created date" : "Létrehozás dátuma",
    "Sort by created date and summary." : "Rendezés létrehozás dátuma és összefoglaló szerint.",
    "Last modified" : "Utoljára módosítva",
    "Sort by last-modified date and summary." : "Rendezés utolsó módosítás dátuma és összefoglaló szerint.",
    "Completed date" : "Teljesítési idő",
    "Priority" : "Prioritás",
    "Sort by priority and summary." : "Rendezés prioritás és összefoglaló szerint.",
    "Manually" : "Manuálisan",
    "Alphabetically" : "Betűrendben",
    "Sort by summary and priority." : "Rendezés összefoglaló és prioritás szerint.",
    "Task is completed" : "Feladat elvégezve",
    "{complete} % completed" : "{complete} % befejezve",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Tomorrow" : "Holnap",
    "Set start date" : "Kezdő dátum beállítása",
    "Set start time" : "Kezdési idő beállítása",
    "Set due date" : "Lejárati dátum beállítása",
    "All day" : "Egész napos",
    "Select a calendar" : "Naptár kiválasztása",
    "Select a classification" : "Besorolás kiválasztása",
    "Select categories" : "Kategóriák kiválasztása",
    "Add this as a new category" : "Hozzáadás új kategóriaként",
    "Task not found!" : "Feladat nem található!",
    "When shared show full event" : "Megosztáskor mutassa a teljes eseményt.",
    "When shared show only busy" : "Megosztáskor csak a foglaltságot mutassa",
    "When shared hide this event" : "Megosztáskor rejtse el ezt az eseményt",
    "No priority assigned" : "Nincs prioritás beállítva",
    "Could not delete the task." : "Nem sikerült törölni a feladatot.",
    "Synchronizing to the server." : "Szinkronizálás a kiszolgálóval.",
    "Task successfully saved to server." : "Feladat sikeresen mentve a kiszolgálóra.",
    "Could not update the task." : "Nem sikerült frissíteni a feladatot.",
    "An error occurred" : "Hiba történt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.13.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/hu.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Fontos",
    "Today" : "Ma",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "Tasks" : "Feladatok",
    "The Tasks app for Nextcloud" : "Feladatok alkalmazás Nextcloud-hoz",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "No users or groups" : "Nincsenek felhasználók vagy csoportok.",
    "can edit" : "módosíthat ",
    "Unshare with {displayName}" : "Megosztás {displayName}-vel törölve",
    "Unable to delete the share." : "Nem lehet törölni a megosztást.",
    "Unable to change permissions." : "Nem lehet változtatni az engedélyeket.",
    "New List" : "Új lista",
    "Cancel" : "Mégsem",
    "Save" : "Mentés",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Edit" : "Szerkesztés",
    "Copy private link" : "Személyes hivatkozás másolása",
    "Copied" : "Másolva",
    "Can not copy" : "Nem lehet másolni",
    "Download" : "Letöltés",
    "Delete" : "Törlés",
    "Unshare" : "Megosztás visszavonása",
    "Calendar link copied to clipboard." : "Naptár hivatkozás a vágólapra másolva.",
    "Calendar link could not be copied to clipboard." : "Naptári hivatkozást nem lehet vágólapra másolni.",
    "An error occurred, unable to delete the calendar." : "Hiba lépett fel, a naptárat nem lehet törölni.",
    "Default list" : "Alapértelmezett lista",
    "Visibility of Smart Collections" : "Okos gyűjtemény láthatósága",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Automatikus",
    "Delete all completed tasks." : "Összes befejezett feladat törlése.",
    "Delete completed tasks." : "Befejezett feladatok törlése.",
    "No errors" : "Nincsenek hibák",
    "Open your browser console for more details" : "Nyisd meg a böngésző konzolját további részletekért",
    "Load all completed tasks." : "Összes befejezett feladat betöltése.",
    "Change sort order" : "Rendezési sorrend váltás",
    "Start date" : "Kezdő dátum",
    "Sort by start date and summary." : "Rendezés kezdő dátum és összefoglaló szerint.",
    "Due date" : "Határidő",
    "Created date" : "Létrehozás dátuma",
    "Sort by created date and summary." : "Rendezés létrehozás dátuma és összefoglaló szerint.",
    "Last modified" : "Utoljára módosítva",
    "Sort by last-modified date and summary." : "Rendezés utolsó módosítás dátuma és összefoglaló szerint.",
    "Completed date" : "Teljesítési idő",
    "Priority" : "Prioritás",
    "Sort by priority and summary." : "Rendezés prioritás és összefoglaló szerint.",
    "Alphabetically" : "Betűrendben",
    "Sort by summary and priority." : "Rendezés összefoglaló és prioritás szerint.",
    "Manually" : "Manuálisan",
    "Task is completed" : "Feladat elvégezve",
    "{complete} % completed" : "{complete} % befejezve",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Tomorrow" : "Holnap",
    "Set start date" : "Kezdő dátum beállítása",
    "Set start time" : "Kezdési idő beállítása",
    "Set due date" : "Határidő beállítása",
    "All day" : "Egész napos",
    "Select a calendar" : "Naptár kiválasztása",
    "Select a classification" : "Besorolás kiválasztása",
    "Select categories" : "Kategóriák kiválasztása",
    "Add this as a new category" : "Hozzáadás új kategóriaként",
    "Task not found!" : "Feladat nem található!",
    "When shared show full event" : "Megosztáskor mutassa a teljes eseményt.",
    "When shared show only busy" : "Megosztáskor csak a foglaltságot mutassa",
    "When shared hide this event" : "Megosztáskor rejtse el ezt az eseményt",
    "Canceled" : "Megszakítva",
    "No priority assigned" : "Nincs prioritás beállítva",
    "Could not delete the task." : "Nem sikerült törölni a feladatot.",
    "Synchronizing to the server." : "Szinkronizálás a kiszolgálóval.",
    "Task successfully saved to server." : "Feladat sikeresen mentve a kiszolgálóra.",
    "Could not update the task." : "Nem sikerült frissíteni a feladatot.",
    "An error occurred" : "Hiba történt"
},
"nplurals=2; plural=(n != 1);");
